@@ -32,6 +32,7 @@
 #ifdef GOFFICE_WITH_GTK
 #include <gtk/gtk.h>
 #endif
+#include <sys/stat.h>
 
 /**
  * SECTION: gog-axis-color-map
@@ -146,7 +147,7 @@ save_name_cb (char const *lang, char const *name, GsfXMLOut *output)
 	gsf_xml_out_start_element (output, "name");
 	if (strcmp (lang, "C"))
 		gsf_xml_out_add_cstr_unchecked (output, "xml:lang", lang);
-	gsf_xml_out_add_cstr_unchecked (output, NULL, name);
+	gsf_xml_out_add_cstr (output, NULL, name);
 	gsf_xml_out_end_element (output);
 }
 
@@ -303,7 +304,18 @@ static void
 gog_axis_color_map_save (GogAxisColorMap const *map)
 {
 	GsfOutput *output = gsf_output_gio_new_for_uri (map->uri, NULL);
-	GsfXMLOut *xml = gsf_xml_out_new (output);
+	GsfXMLOut *xml;
+	if (output == NULL) {
+		char *dir = go_dirname_from_uri (map->uri, TRUE);
+		int res = g_mkdir_with_parents (dir, 0777);
+		g_free (dir);
+		if (res < 0) {
+			g_warning ("[GogAxisColorMap]: Could not save color map to %s", map->uri);
+			return;
+		}
+		output = gsf_output_gio_new_for_uri (map->uri, NULL);
+	}
+	xml = gsf_xml_out_new (output);
 	gsf_xml_out_start_element (xml, "GogAxisColorMap");
 	gog_axis_color_map_write (GO_PERSIST (map), xml);
 	gsf_xml_out_end_element (xml);
@@ -377,8 +389,10 @@ gog_axis_color_map_prep_sax (GOPersist *gp, GsfXMLIn *xin, xmlChar const **attrs
 	state->langs = g_get_language_names ();
 	state->name_lang_score = G_MAXINT;
 	state->color_stops = NULL;
-	if (!xml)
+	if (!xml) {
 		xml = gsf_xml_in_doc_new (color_map_dtd, NULL);
+		go_xml_in_doc_dispose_on_exit (&xml);
+	}
 	gsf_xml_in_push_state (xin, xml, state, (GsfXMLInExtDtor) parse_done_cb, attrs);
 }
 
@@ -906,8 +920,10 @@ color_map_load_from_uri (char const *uri)
 	state.langs = g_get_language_names ();
 	state.name_lang_score = G_MAXINT;
 	state.color_stops = NULL;
-	if (!xml)
+	if (!xml) {
 		xml = gsf_xml_in_doc_new (color_map_dtd, NULL);
+		go_xml_in_doc_dispose_on_exit (&xml);
+	}
 	if (!gsf_xml_in_doc_parse (xml, input, &state))
 		g_warning ("[GogAxisColorMap]: Could not parse %s", uri);
 	if (state.map != NULL) {
@@ -935,10 +951,12 @@ color_maps_load_from_dir (char const *path)
 	while ((d_name = g_dir_read_name (dir)) != NULL) {
 		char *fullname = g_build_filename (path, d_name, NULL);
 		char *uri = go_filename_to_uri (fullname);
-		char *mime_type = go_get_mime_type (uri);
-		if (!strcmp (mime_type, "application/xml")) /* we don't have a better one */
+		size_t n = strlen (uri);
+		 /* checking for mime type does not look safe, so we check for the
+		 extension. TRhings might fail later if the file does not describe a
+		 valid color map */
+		if (n >= 4 && !strcmp (uri + n - 4, ".map"))
 			color_map_load_from_uri (uri);
-		g_free (mime_type);
 		g_free (uri);
 		g_free (fullname);
 	}
