@@ -270,7 +270,6 @@ cb_key_press_event (G_GNUC_UNUSED GtkWidget *wrapper,
 		    GdkEventKey *event,
 		    GraphGuruTypeSelector *typesel)
 {
-	GtkCornerType corner;
 	int col, row;
 	double x, y;
 	GogPlotType const *type = g_object_get_data (
@@ -281,24 +280,24 @@ cb_key_press_event (G_GNUC_UNUSED GtkWidget *wrapper,
 	col = type->col;
 	row = type->row;
 
-	switch (event->keyval){
-	case GDK_KEY_KP_Left:	case GDK_KEY_Left:
-		corner = GTK_CORNER_BOTTOM_RIGHT;
+	switch (event->keyval) {
+	case GDK_KEY_KP_Left:
+	case GDK_KEY_Left:
 		--col;
 		break;
 
-	case GDK_KEY_KP_Up:	case GDK_KEY_Up:
-		corner = GTK_CORNER_BOTTOM_RIGHT;
+	case GDK_KEY_KP_Up:
+	case GDK_KEY_Up:
 		--row;
 		break;
 
-	case GDK_KEY_KP_Right:	case GDK_KEY_Right:
-		corner = GTK_CORNER_TOP_LEFT;
+	case GDK_KEY_KP_Right:
+	case GDK_KEY_Right:
 		++col;
 		break;
 
-	case GDK_KEY_KP_Down:	case GDK_KEY_Down:
-		corner = GTK_CORNER_TOP_LEFT;
+	case GDK_KEY_KP_Down:
+	case GDK_KEY_Down:
 		++row;
 		break;
 
@@ -1013,7 +1012,7 @@ graph_guru_init_format_page (GraphGuruState *s)
 	g_object_get (G_OBJECT (rend), "view", &(s->graph_view), NULL);
 	s->selection_changed_handler = g_signal_connect (G_OBJECT (s->graph_view), "selection-changed",
 							 G_CALLBACK (cb_graph_selection_changed), s);
-	g_object_unref (G_OBJECT (rend));
+	g_object_unref (rend);
 
 	w = go_gtk_builder_get_widget (s->gui, "prop_alignment");
 	s->prop_container = GTK_CONTAINER (w);
@@ -1162,8 +1161,9 @@ typesel_set_selection_color (GraphGuruTypeSelector *typesel)
 
 	gtk_style_context_get_background_color (style_context,
 	                                        gtk_widget_has_focus (typesel->canvas)
-											? GTK_STATE_SELECTED : GTK_STATE_ACTIVE,
-                                            &rgba);
+						? GTK_STATE_FLAG_SELECTED
+						: GTK_STATE_FLAG_ACTIVE,
+						&rgba);
 	if (rgba.alpha > 0.40)
 				rgba.alpha = 0.40;
 	select_color = GO_COLOR_FROM_GDK_RGBA (rgba);
@@ -1268,7 +1268,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	g_object_set_data_full (G_OBJECT (selector),
 		"state", typesel, (GDestroyNotify) g_free);
 
-	g_object_unref (G_OBJECT (gui));
+	g_object_unref (gui);
 
 	return selector;
 }
